@@ -7,10 +7,26 @@ class TwitterOEmbedder(object):
     def __init__(self, app=None, cache=None, debug=None):
         if app and cache:
             self.init(app, cache, debug)
-    def init(self, app, cache, debug=None):
+
+    def init(self, app, cache, timeout=None, debug=None):
+        def _cache_key(func, *args, **kwargs):
+            return (args[0], kwargs.get('omit_script', False))
+
+        twitter_timeout = 60*60*24*365
+        if timeout > twitter_timeout:
+            raise Exception("TwitterOEmbedder: Cache expiry should not exceed 1 year "
+                            "per Twitter API specification")
+        max_timeout = {'saslmemcached':60*60*24*30,
+                       'simple': twitter_timeout}
+
+        if not timeout:
+            default_timeout = app.config.get('CACHE_DEFAULT_TIMEOUT', 300)
+            timeout = min(max_timeout.get(app.config.get('CACHE_TYPE', default_timeout)),
+                          twitter_timeout)
+
         @app.context_processor
         def tweet_processor():
-            @cache.memoize(timeout=60*60*24*356)
+            @cache.memoize(timeout=timeout)
             def oembed_tweet(tweet_id,
                              access_token=app.config['TWITTER_ACCESS_TOKEN'],
                              token_secret=app.config['TWITTER_TOKEN_SECRET'],
@@ -31,4 +47,5 @@ class TwitterOEmbedder(object):
                     else:
                         return ''
                 return tweet_html
+            oembed_tweet.make_cache_key = _cache_key
             return dict(oembed_tweet=oembed_tweet)
